@@ -125,7 +125,13 @@ VMProxy gst_interpreter_proxy = {
   _gst_dladdsearchdir,
   _gst_dlpushsearchpath,
   _gst_dlpopsearchpath,
-  _gst_wakeup
+  _gst_wakeup,
+
+  /* New in 3.2.5.  */
+  _gst_uint_to_oop,
+
+  /* New in 3.3.  */
+  _gst_set_event_loop_handlers
 };
 
 /* Functions in comp.h.  */
@@ -264,6 +270,12 @@ gst_int_to_oop (long i)
   return _gst_int_to_oop (i);
 }
 
+OOP
+gst_uint_to_oop (unsigned long i)
+{
+  return _gst_uint_to_oop (i);
+}
+
 OOP
 gst_float_to_oop (double f)
 {
@@ -589,3 +601,11 @@ gst_relocate_path (const char *path)
   return _gst_relocate_path (path);
 }
 
+
+/* Functions in events.h.  */
+mst_Boolean
+gst_set_event_loop_handlers(mst_Boolean (*poll) (int ms),
+			    void (*dispatch) (void))
+{
+  return _gst_set_event_loop_handlers(poll, dispatch);
+}
