@@ -102,19 +102,25 @@ extern SigHandler _gst_set_signal_handler (int signum,
 					   SigHandler handlerFunc)
   ATTRIBUTE_HIDDEN;
 
-/* Given a KIND of timer (process timer, real-time timer, etc.,
-   establish FUNC to be called when DELTAMILLI milliseconds have
-   passed according to that counter.  */
-extern void _gst_signal_after (int deltaMilli,
-			       SigHandler func,
-			       int kind)
+/* Establish FUNC to be called when DELTAMILLI milliseconds of
+   process time have passed.  */
+extern void _gst_sigvtalrm_every (int deltaMilli,
+			       SigHandler func)
+  ATTRIBUTE_HIDDEN;
+
+/* Cancel an established SIGALRM */
+extern void _gst_sigalrm_cancel (void)
+  ATTRIBUTE_HIDDEN;
+
+/* Establish SIGALRM to be called when the nanosecond clock reaches NSTIME
+   nanoseconds.  */
+extern void _gst_sigalrm_at (int64_t nsTime)
   ATTRIBUTE_HIDDEN;
 
 /* Initialize system dependent stuff.  */
 extern void _gst_init_sysdep (void)
   ATTRIBUTE_HIDDEN;
-
-extern void _gst_init_sysdep_win32 (void)
+extern void _gst_init_sysdep_timer (void)
   ATTRIBUTE_HIDDEN;
 
 /* Arrange so that FUNC is called when I/O becomes possible on
@@ -134,10 +140,14 @@ extern void _gst_debug (void)
 extern void _gst_usleep (int us)
   ATTRIBUTE_HIDDEN;
 
-/* Returns the local time since midnight in milliseconds */
+/* Returns a (hopefully) monotonic time value in milliseconds */
 extern uint64_t _gst_get_milli_time (void)
   ATTRIBUTE_HIDDEN;
 
+/* Returns a (hopefully) monotonic time value in nanoseconds */
+extern uint64_t _gst_get_ns_time (void)
+  ATTRIBUTE_HIDDEN;
+
 /* Returns the time in seconds since midnight Jan 1, 1970 (standard UNIX
    type time).  */
 extern time_t _gst_get_time (void)
@@ -223,36 +233,29 @@ extern int _gst_open_file (const char *filename,
   ATTRIBUTE_HIDDEN;
 
 /* Read SIZE bytes into BUFFER from the file descriptor, FD.  */
-extern int _gst_read (int fd,
-		      PTR buffer,
-		      int size)
-  ATTRIBUTE_HIDDEN;
-
-/* Ensures that exactly SIZE bytes of BUFFER are written into the
-   file descriptor, FD.  */
-extern int _gst_full_write (int fd,
-		            PTR buffer,
-		            int size)
+extern ssize_t _gst_read (int fd,
+		          PTR buffer,
+		          size_t size)
   ATTRIBUTE_HIDDEN;
 
 /* Write SIZE bytes of BUFFER into the file descriptor, FD.  */
-extern int _gst_write (int fd,
-		       PTR buffer,
-		       int size)
+extern ssize_t _gst_write (int fd,
+		           PTR buffer,
+		           size_t size)
   ATTRIBUTE_HIDDEN;
 
-/* Read SIZE bytes into BUFFER from the file descriptor, FD.  */
-extern int _gst_recv (int fd,
-		      PTR buffer,
-		      int size,
-		      int flags)
+/* Read SIZE bytes into BUFFER from the file descriptor for a socket, FD.  */
+extern ssize_t _gst_recv (int fd,
+		          PTR buffer,
+		          size_t size,
+		          int flags)
   ATTRIBUTE_HIDDEN;
 
-/* Write SIZE bytes of BUFFER into the socket descriptor, FD.  */
-extern int _gst_send (int fd,
-		      PTR buffer,
-		      int size,
-		      int flags)
+/* Write SIZE bytes of BUFFER into the file descriptor for a socket, FD.  */
+extern ssize_t _gst_send (int fd,
+		          PTR buffer,
+		          size_t size,
+		          int flags)
   ATTRIBUTE_HIDDEN;
 
 /* Writes a debug message with the given formatting.  */
